"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EnumValuesSortedAlphabetically = EnumValuesSortedAlphabetically;

var _validation_error = require("../validation_error");

var _listIsAlphabetical = _interopRequireDefault(require("../util/listIsAlphabetical"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function EnumValuesSortedAlphabetically(configuration, context) {
  const ruleKey = 'enum-values-sorted-alphabetically';
  return {
    EnumTypeDefinition(node, key, parent, path, ancestors) {
      const enumValues = node.values.map(val => {
        return val.name.value;
      });
      const {
        sortOrder = 'alphabetical'
      } = configuration.getRulesOptions()[ruleKey] || {};
      const {
        isSorted,
        sortedList
      } = (0, _listIsAlphabetical.default)(enumValues, sortOrder);

      if (!isSorted) {
        context.reportError(new _validation_error.ValidationError(ruleKey, `The enum \`${node.name.value}\` should be sorted in ${sortOrder} order. ` + `Expected sorting: ${sortedList.join(', ')}`, [node]));
      }
    }

  };
}