"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TypeFieldsSortedAlphabetically = TypeFieldsSortedAlphabetically;

var _validation_error = require("../validation_error");

var _listIsAlphabetical = _interopRequireDefault(require("../util/listIsAlphabetical"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function TypeFieldsSortedAlphabetically(configuration, context) {
  const ruleKey = 'type-fields-sorted-alphabetically';
  return {
    ObjectTypeDefinition(node) {
      const fieldList = (node.fields || []).map(field => field.name.value);
      const {
        sortOrder = 'alphabetical'
      } = configuration.getRulesOptions()[ruleKey] || {};
      const {
        isSorted,
        sortedList
      } = (0, _listIsAlphabetical.default)(fieldList, sortOrder);

      if (!isSorted) {
        context.reportError(new _validation_error.ValidationError(ruleKey, `The fields of object type \`${node.name.value}\` should be sorted in ${sortOrder} order. ` + `Expected sorting: ${sortedList.join(', ')}`, [node]));
      }
    }

  };
}