"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = listIsAlphabetical;

var _arraysEqual = _interopRequireDefault(require("./arraysEqual"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @summary Returns `true` if the list is in alphabetical order,
 *   or an alphabetized list if not
 * @param {String[]} list Array of strings
 * @return {Object} { isSorted: Bool, sortedList: String[] }
 */
function listIsAlphabetical(list, sortOrder = 'alphabetical') {
  let sortFn;

  if (sortOrder === 'lexicographical') {
    sortFn = (a, b) => a.localeCompare(b);
  }

  const sortedList = list.slice().sort(sortFn);
  return {
    isSorted: (0, _arraysEqual.default)(list, sortedList),
    sortedList
  };
}